<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nn">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Det finst eit liv utanfor nettlesaren!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Versjon %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Lisensiert til: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 er fri programvare, men utviklinga tek dyrebar tid.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Ver venleg og &lt;a href=&apos;%1&apos;&gt;doner&lt;/a&gt; for å støtta vidare utvikling av %2.</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Omset %1 til morsmålet ditt med %2</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation>Oppretta av %1</translation>
    </message>
    <message>
        <source>Open-source software</source>
        <translation>Åpen kildekode programvare</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Ikonet er utforma av %1.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Utgjeve under &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Om</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Skriv inn lisensinformasjonen din</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;E-post:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Kode:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Ver venleg og lisensier %1</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation>Fullversjonen lar deg se videoer uten avbrudd.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Ved å kjøpa den fullstendige utgåva, støttar du arbeidet lagt inn i å skapa %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Bruk demoen</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Skriv inn lisens</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Kjøp lisens</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation>Nedlasting</translation>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>Etter %1</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation><numerusform>Du har %n nye video(er)</numerusform><numerusform>Du har %n nye video(er)</numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>Alle videoar</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Usette videoar</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>Sist oppdatert</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>Sist lagt til</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>Sist sett</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>Mest sett</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Sorter etter</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>Merk alle som sett</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>Vis oppdaterte</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>Du har ingen tingingar. Bruk stjernesymbolet for å tinga kanalar.</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>Alle videoar</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Usette videoar</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation>Merk som sett</translation>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation>Avslutte abonnementet</translation>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>Ingen oppdaterte tingingar enno.</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation>Akkurat nå</translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation><numerusform>%n time(r) siden</numerusform><numerusform>%n time(r) siden</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation><numerusform>%n dag(er) siden</numerusform><numerusform>%n dag(er) siden</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation><numerusform>%n måned(er) siden</numerusform><numerusform>%n måned(er) siden</numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation>K</translation>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation>M</translation>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>%1 views</source>
        <translation>%1 visingar</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation><numerusform>%n uke(er) siden</numerusform><numerusform>%n uke(er) siden</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n year(s) ago</source>
        <translation><numerusform>%n år siden</numerusform><numerusform>%n år siden</numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>byte</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>byte/sek</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>KB/sek</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>MB/sek</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>sekund</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutt</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 gjenstår</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1 lasta ned på %2</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Nedlasting ferdig</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation><numerusform>%n nedlasting(er)</numerusform><numerusform>%n nedlasting(er)</numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Endra stad …</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Vel nedlastingsmappe</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Nedlastingsmappe endra.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Nedlastingar som er i gong vil likevel lagrast i den førre mappa.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Lastar ned til: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Nedlastingar</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation>Den kjørbare filen har blitt temperert, kanskje av et virus.</translation>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation>%1 vil ikke kjøre. Prøv å installere på nytt.</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Slutte</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Installer på nytt</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Spel av</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Spel av/pause</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stopp</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Stopp avspelinga etter denne videoen</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Neste video</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Førre video</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Auk lydvolumet</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Senk lydvolumet</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Lydlaus</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Søk framover</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Søk bakover</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>Søk</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>Finn videoar og kanalar med nøkkelord</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Bla gjennom</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>Bla gjennom videoar etter kategory</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Tingingar</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>Kanaltingingar</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Gjer deg sjølv komfortabel</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Vindauge</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimer</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Stopp</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Stoppar avspeling og går tilbake til søkjevisinga</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>&amp;Førre</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Gå til førre spor</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;Hopp over</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Hopp til neste video</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Spel av</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Gjenoppta avspeling</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Fullskjerm</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Fullskjermvising</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>&amp;Kompakt modus</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Gøym spelelista og verktøylinja</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>Opna &amp;YouTube-sida</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Gå til video-sida på YouTube og set avspelinga på pause</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>Kopier YouTube-&amp;lenkja</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Kopier denne YouTube video-lenkja til utklippstavla</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>Kopier &amp;URL-en til videostraumen</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Kopier denne videostraumlenkja til utklippstavla</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>Finn &amp;delane av videoen</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Finn andre deler av videoen, vonleg i rett følgje</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Fjern</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Fjern valde videoar frå spelelista</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Flytt &amp;opp</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Flytt opp valde videoar i spelelista</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Flytt &amp;ned</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Flytt ned valde videoar i spelelista</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>&amp;Tøm siste søk</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Fjern all søkjehistorie. Kan ikkje angrast.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Avslutt</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Farvel</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Nettstad</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 på internett</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>&amp;Doner</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Vi håpar du kan bidra til vidare utvikling av %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Om</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Informasjon om %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Søk</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Lydlaus</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>Start avspelinga &amp;manuelt</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>Spel av videoar manuelt</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;Nedlastingar</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Vis detaljar om videonedlasting</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Nedlasting</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Last ned denne videoen</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation>Ta et &amp;øyeblikksbilde</translation>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>&amp;Ting kanal</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>Del denne videoen med %1</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>&amp;Epost</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Epost</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Steng</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>&amp;Vis over andre</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>&amp;Stopp etter denne videoen</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Meld frå om feil …</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>&amp;Raffiner søk …</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>Meir …</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>&amp;Liknande videoar</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>Sjå videoar som liknar på denne</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>Opna i &amp;nettlesaren …</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation>Begrenset modus</translation>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation>Skjul videoer som kan inneholde upassende innhold</translation>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation>Slå på &amp;menylinje</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>Meny</translation>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>&amp;Elsker du %1? Rangere det!</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Kjøp %1 …</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Program</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Avspeling</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Speleliste</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>&amp;Del</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Vising</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hjelp</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Trykk på %1 for å auka lydvolumet, %2 for å senka</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>Vel stad for innhald</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Opnar %1</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Vil du avslutta %1 medan ei nedlasting er i gang?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Vis du stenger %1 no, vil nedlastinga avbrytast</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Steng og avbryt nedlastinga</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Vent medan nedlastinga vert fullførd</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Feil: %1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Set avspeling på pause</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation>&amp;Laster inn...</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Forlat &amp;fullskjerm</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Tid igjen: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volum %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Lydlaust er på</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Lydlaust er av</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Maksimum videodefinisjon sett til %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Privatlivet ditt er no sikkert</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Nedlastingar fullførde</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation>Du kan fortsatt få tilgang til menylinjen ved å trykke på ALT-tasten</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Du kan no lima inn YouTube-lenkja i eit anna program</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Du kan no lima inn videostraumlenkja i eit anna program</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Denne lenkja vil berre vera gyldig i ei avgrensa tid.</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Lastar ned %1</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>av</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>del</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>episode</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>Send frå %1</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>Slutt å tinga %1</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>Ting %1</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation>Byttet til %1</translation>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation>Avsluttet abonnementet på %1</translation>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation>Abonnerte på %1</translation>
    </message>
    <message>
        <source>Rewind %1 seconds</source>
        <translation>Spol %1 sekunder tilbake</translation>
    </message>
    <message>
        <source>Fast forward %1 seconds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>channel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Ny utgåve av %1 tilgjengeleg!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 er no tilgjengeleg. Du har %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Vil du lasta ned no?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Hopp over denne utgåva</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Minn på meg seinare</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Installer oppdatering</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Lim inn</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 av %2 (%3) — %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Gjer klar</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Feil</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Ferdig</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Stoppa</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Avbryt nedlasting</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>Vis i %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Opna foreldermappe</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Start nedlasting på nytt</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>Vis %1 til</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Ingen videoar</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Ingen fleire videoar</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>Sorter etter</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Relevans</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dato</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>Vis kor mange</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Rangering</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>Når som helst</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>I dag</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7 dagar</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30 dagar</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Varigskap</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>Kort</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Middels</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>Lang</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>Mindre enn 4 minutt</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>Mellom 4 og 20 minutt</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>Meir enn 20 minutt</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kvalitet</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Ferdig</translation>
    </message>
    <message>
        <source>This year</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>HD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>4K</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>HDR</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>Ferdig</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Søk</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Velkomen til &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>for å å sjå videoar.</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>eit nøkkelord</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Skriv</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Siste søkjeord</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>Siste kanalar</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Kjøpfullversjonen</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Need a remote control for %1? Try %2!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>I keep improving %1 to make it the best I can. Support this work!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>An update is ready to be installed. Quit and install update.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Tilbake</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>Fram til %1</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>Tilbake til %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>Forbetra søket</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>Meinte du: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Endra stad …</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>Mest populære</translation>
    </message>
    <message>
        <source>Trending</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>News</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Movies</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gaming</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>Lastar ned oppdatering …</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Updater</name>
    <message>
        <source>Check for Updates...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Version %1 is available...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading version %1...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Restart to Update</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Version %1 download failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Check for Updates</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Download Update</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading update...</source>
        <translation>Lastar ned oppdatering …</translation>
    </message>
    <message>
        <source>Retry Update Download</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You have the latest version.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Version %1 is available.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>An update has been downloaded and is ready to be installed.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>YTJSVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Kan ikkje henta videostraumen til %1</translation>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>Algerie</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>Argentina</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>Australia</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>Belgia</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>Brasil</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>Kanada</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>Chile</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>Kolombia</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>Tsjekkia</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>Egypt</translation>
    </message>
    <message>
        <source>France</source>
        <translation>Frankrike</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>Tyskland</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>Ghana</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Hellas</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>Hong Kong</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>Ungarn</translation>
    </message>
    <message>
        <source>India</source>
        <translation>India</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonesia</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>Irland</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>Israel</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>Italia</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>Japan</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>Jordan</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>Kenya</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>Malaysia</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>Mexico</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>Marocco</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>Nederland</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>Ny-Zealand</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>Nigeria</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>Peru</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>Filippinane</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>Polen</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>Russland</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>Saudi-Arabia</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>Singapore</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>Sør-Afrika</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>Sør-Korea</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>Spania</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>Sverige</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>Taiwan</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>Tunisia</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>Tyrkia</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>Uganda</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>Sameinte Arabiske Emiratar</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>Storbritannia</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>Jemen</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>Heile verda</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Kan ikkje henta videostraumen til %1</translation>
    </message>
</context>
<context>
    <name>updater::DefaultUpdater</name>
    <message>
        <source>There are currently no updates available.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>updater::Dialog</name>
    <message>
        <source>You already have the latest version</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading %1 %2...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Ny utgåve av %1 tilgjengeleg!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 er no tilgjengeleg. Du har %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Vil du lasta ned no?</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Minn på meg seinare</translation>
    </message>
    <message>
        <source>Download Update</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>